aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--miscutils/time.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/miscutils/time.c b/miscutils/time.c
index 19b0b44c9..6a4de9837 100644
--- a/miscutils/time.c
+++ b/miscutils/time.c
@@ -69,9 +69,9 @@ static void resuse_end(pid_t pid, resource_t *resp)
{
pid_t caught;
/* Ignore signals, but don't ignore the children. When wait3
* returns the child process, set the time the command finished. */
- while ((caught = wait3(&resp->waitstatus, 0, &resp->ru)) != pid) {
+ while ((caught = wait4(-1, &resp->waitstatus, 0, &resp->ru)) != pid) {
if (caught == -1 && errno != EINTR) {
bb_perror_msg("wait");
return;
@@ -69,9 +69,9 @@ static void resuse_end(pid_t pid, resource_t *resp)
{
pid_t caught;
- /* Ignore signals, but don't ignore the children. When wait3
+ /* Ignore signals, but don't ignore the children. When wait4
* returns the child process, set the time the command finished. */